@@ -79,24 +79,24 @@ def rename(path, options):
         config = get_config(options.config)
 
         for episode in _file.episodes:
-            canonical = config.get('canonical',
+            canonical = config.get('canonical', show=_file.show_name,
                 default=episode._file.show_name, override=options.canonical)
 
             ep_kwargs = {'library': options.library, 'canonical': canonical}
             episode.title = tv.retrieve_episode_title(episode, **ep_kwargs)
 
         show = config.get_output(_file.show_name, override=options.show_override)
-        the = config.get('the', override=options.the)
+        the = config.get('the', show=_file.show_name, override=options.the)
         _file.show_name = tv.format_show_name(show, the=the)
 
-        _file.set_output_format(config.get('format',
+        _file.set_output_format(config.get('format', show=_file.show_name,
             default=_file.output_format, override=options.output_format))
 
-        organise = config.get('organise',
+        organise = config.get('organise', show=_file.show_name,
             default=False, override=options.organise)
-        rename_dir = config.get('renamed',
+        rename_dir = config.get('renamed', show=_file.show_name,
             default=working, override=options.rename_dir)
-        specials_folder = config.get('specials_folder',
+        specials_folder = config.get('specials_folder', show=_file.show_name,
             default='Season 0', override=options.specials_folder)
         path = tv.build_path(
             _file,
