@@ -4,6 +4,11 @@ import os
 import re
 import shutil
 
+try:
+    from collections import OrderedDict
+except ImportError:  # python 2
+    from tvrenamr.vendor.ordereddict import OrderedDict
+
 from . import errors
 from .libraries import TheTvDb, TvRage
 
@@ -122,13 +127,8 @@ class File(object):
             if e.number is None:
                 raise errors.MissingInformationException('An episode number')
 
-    def set_output_format(self, user_format, config):
-        if user_format is None:
-            config_format = config.get(self.show_name, 'format')
-            if config_format is not None:
-                self.output_format = config_format
-        else:
-            self.output_format = user_format
+    def set_output_format(self, user_format):
+        self.output_format = user_format
 
     def user_overrides(self, show_name, season, episode):
         if show_name:
@@ -146,12 +146,11 @@ class File(object):
 
 
 class TvRenamr(object):
-    def __init__(self, working_dir, config, debug=False, dry=False, cache=True):
+    def __init__(self, working_dir, debug=False, dry=False, cache=True):
         self.cache = cache
         self.working_dir = working_dir
         self.dry = dry
         self.debug = debug
-        self.config = config
 
     def remove_part_from_multiple_episodes(self, show_name):
         """Remove the string "Part " from a filename.
@@ -173,6 +172,11 @@ class TvRenamr(object):
         already covered.
 
         """
+        try:
+            fn = fn.decode('utf-8')
+        except AttributeError:  # python 3
+            pass
+
         fn = self._santise_filename(fn)
         log.log(22, 'Renaming: {0}'.format(fn))
 
@@ -185,7 +189,7 @@ class TvRenamr(object):
 
         return self._build_credentials(fn, matches)
 
-    def retrieve_episode_title(self, episode, library='thetvdb', canonical=None):
+    def retrieve_episode_title(self, episode, library=None, canonical=None):
         """Retrieves the title of a given episode.
 
         The series name, season and episode numbers must be specified to get
@@ -195,20 +199,11 @@ class TvRenamr(object):
         The first library defaults to The Tv DB.
 
         """
-        libraries = [
-            TheTvDb,
-            TvRage
-        ]
-        [libraries.insert(0, libraries.pop(libraries.index(lib)))
-            for lib in libraries if lib.__name__.lower() == library]
+        libraries = self._get_libraries(library)
 
-        # TODO: Make this bit not suck.
-        if canonical:
+        if canonical is not None:
             episode._file.show_name = canonical
-        else:
-            episode._file.show_name = self.config.get(episode._file.show_name,
-                                                      'canonical',
-                                                      episode._file.show_name)
+
         log.debug('Show Name: {0}'.format(episode._file.show_name))
 
         # loop the libraries until one works
@@ -228,21 +223,13 @@ class TvRenamr(object):
         log.info('Episode: {0}'.format(self.lookup.title))
         return self.lookup.title
 
-    def format_show_name(self, show_name, the=None, override=None):
-        if the is None:
-            the = self.config.get(show_name, 'the')
-
-        try:
-            show_name = self.config.get_output(show_name)
-            log.debug('Using config output name: {0}'.format(show_name))
-        except errors.ShowNotInConfigException:
+    def format_show_name(self, show_name, the=False):
+        if show_name is None:
             show_name = self.lookup.show
             msg = 'Using the formatted show name retrieved by the library: {0}'
             log.debug(msg.format(show_name))
-
-        if override is not None:
-            show_name = override
-            log.debug('Overrode show name with: {0}'.format(show_name))
+        else:
+            log.debug('Using config output name: {0}'.format(show_name))
 
         if the is True:
             show_name = self._move_leading_the_to_trailing_the(show_name)
@@ -251,7 +238,7 @@ class TvRenamr(object):
 
         return show_name
 
-    def build_path(self, _file, rename_dir=None, organise=None, specials_folder=None):
+    def build_path(self, _file, rename_dir, organise=False, specials_folder=None):
         """Build the full destination path and filename of the renamed file.
 
         By default the format is:
@@ -265,11 +252,6 @@ class TvRenamr(object):
         season and show folders, i.e. Show/Season 1/episodes
 
         """
-        if rename_dir is None:
-            rename_dir = self.config.get(_file.show_name, 'renamed', self.working_dir)
-
-        if organise is None:
-            organise = self.config.get(_file.show_name, 'organise')
         if organise is True:
             args = [rename_dir, _file.show_name, _file.season, specials_folder]
             rename_dir = self._build_organise_path(*args)
@@ -337,8 +319,8 @@ class TvRenamr(object):
         Show name and season number of an episode dictate the folder structure.
         """
         season = 'Season {0}'.format(season_number)
-        if season_number is 0:  # specials folder
-            season = specials or self.config.get(show_name, 'specials_folder')
+        if season_number is 0 and specials is not None:  # specials folder
+            season = specials
 
         path = os.path.join(start_path, show_name, season)
 
@@ -407,6 +389,19 @@ class TvRenamr(object):
 
         return regex
 
+    def _get_libraries(self, library):
+        lookup = OrderedDict({
+            'thetvdb': TheTvDb,
+            'tvrage': TvRage,
+        })
+        libraries = list()
+        try:
+            libraries.append(lookup[library])
+        except KeyError:
+            libraries = list(lookup.values())
+
+        return libraries
+
     def _move_leading_the_to_trailing_the(self, show_name):
         """Moves the leading 'The' of a show name to a trailing 'The'.
 
